@@ -132,8 +132,12 @@ class PartitionFetcher(object):
                          + str(self.partitionId))
 
         # try to lock partition from HBase, if failed, set to UNLOCKED and return;
-        if not self.steal_partition():
-            self.update_state(TASK_STATE.UNLOCKED)
+        try:
+            if not self.steal_partition():
+                self.update_state(TASK_STATE.UNLOCKED)
+                return
+        except Exception as e:
+            self.logger.error("Exception in steal_partition " + str(traceback.format_exc()))
             return
 
         # query start offset to read, if failed, clean and return;
@@ -278,7 +282,10 @@ class PartitionFetcher(object):
         # get the successfully locked partition
         successPartitionList = lockResponse.successPartitions
         if len(successPartitionList) > 0:
-            assert successPartitionList[0] == self.partitionId
+            try
+                assert successPartitionList[0] == self.partitionId
+            except AssertionError as e:
+                raise e
             self.logger.info("Worker: " + self.workerId + " success to lock partitions: "
                              + str(self.partitionId))
             return True
