@@ -198,7 +198,10 @@ def is_offset_out_of_range(throwable=None):
 
 def get_topic_name_by_resource_name(topicTalosResourceName=None):
     itemList = topicTalosResourceName.split(Constants.TALOS_IDENTIFIER_DELIMITER)
-    assert len(itemList) >= 3
+    try:
+        assert len(itemList) >= 3
+    except AssertionError as e:
+        raise e
     return itemList[len(itemList) - 2]
 
 
